# Copyright (c) 2000-2005, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with_gcj %{!?_without_gcj:1}%{?_without_gcj:0}

Name:           jgraph
Version:        5.13.0.0
Release:        2%{?dist}
Summary:        Java-based Diagram Component and Editor
License:        BSD
Group:          Development/Libraries
URL:            http://www.jgraph.com/
Source0:        http://downloads.sourceforge.net/project/jgraph/jgraph/%{version}/jgraph-latest-bsd-src.jar
Patch0:         jgraph-5.13.0.0-javadoc-crosslink.patch

BuildRequires:  ant >= 0:1.6
BuildRequires:  java-devel
BuildRequires:  java-javadoc
BuildRequires:  jpackage-utils >= 0:1.6
BuildRequires:  dos2unix
Requires:       jpackage-utils

%if %{with_gcj}
BuildRequires:    java-gcj-compat-devel >= 1.0.31
Requires(post):   java-gcj-compat >= 1.0.31
Requires(postun): java-gcj-compat >= 1.0.31
%else
BuildArch:      noarch
%endif

BuildRoot:      %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

%description
JGraph is the a lightweight and feature-rich graph component
for Java. It provides automatic 2D layout and routing for diagrams.
Object and relations can be displayed in any Swing UI via provided
zoomable compontent. It is accompanied by diagram editor, JGraphpad.


%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation

%description javadoc
%{summary}.

%prep
%setup -q -c
%patch0 -p1 -b .javadoc-crosslink
# remove all binary libs
find -type f -name "*.jar" | xargs -t rm
# convert some line endings
dos2unix -q LICENSE examples/com/jgraph/example/SerialGraph.java

%build
export CLASSPATH=
export OPT_JAR_LIST=:
ant -Dbuild.sysclasspath=only

# Remove copies of source so that we don't confuse
# the debuginfo finder
rm -rf build/src dist/%{name}-%{version}-src

%install
rm -rf $RPM_BUILD_ROOT

# jars
mkdir -p $RPM_BUILD_ROOT%{_javadir}
cp -p build/lib/%{name}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)

# javadoc
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr build/doc/api/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}

# maven
%add_to_maven_depmap com.jgraph %{name} %{version} JPP %{name}

# gcj stuff
%if %{with_gcj}
%{_bindir}/aot-compile-rpm
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap
%if %{with_gcj}
if [ -x %{_bindir}/rebuild-gcj-db ] 
then
%{_bindir}/rebuild-gcj-db
fi
%endif

%postun
%update_maven_depmap
%if %{with_gcj}
if [ -x %{_bindir}/rebuild-gcj-db ] 
then
%{_bindir}/rebuild-gcj-db
fi
%endif

%files
%defattr(-,root,root,-)
%doc LICENSE README examples/
%{_javadir}/%{name}.jar
%{_javadir}/%{name}-%{version}.jar
%config(noreplace) %{_mavendepmapfragdir}/%{name}
%if %{with_gcj}
%attr(-,root,root) %{_libdir}/gcj/%{name}
%endif

%files javadoc
%defattr(-,root,root,-)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%changelog
* Tue Nov 10 2009 Lubomir Rintel <lkundrak@v3.sk> - 5.13.0.0-2
- Add missing jpackage-utils require (D Haley)

* Mon Nov 09 2009 Lubomir Rintel <lkundrak@v3.sk> - 5.13.0.0-1
- Rebase to a later version

* Sat Oct 21 2009 Lubomir Rintel <lkundrak@v3.sk> - 5.12.2.1-3
- Make life easier for find-debuginfo

* Sat Oct 21 2009 Lubomir Rintel <lkundrak@v3.sk> - 5.12.2.1-2
- Clarified summary and description
- README suggests license is LGPLv2
- Do not override file modes
- Fix Groups

* Tue Dec 16 2008 Mary Ellen Foster <mefoster at gmail.com> - 5.12.2.1-1
- Import spec file from jpackage
- Updated to latest upstream 5.1.2.1
- Added maven fragments and additional documentation
- Used dos2unix to convert file endings
- Removed Epoch -- not sure if that's kosher or not ...
- Added gcj stuff

* Wed Oct 08 2008 David Walluck <dwalluck@redhat.com> 0:5.12.1.0-1
- 5.12.1.0

* Tue Jul 11 2006 Fernando Nasser <fnasser@redhat.com> - 0:5.8.2.1-2jpp
- Add missing header

* Wed Jun 07 2006 Ralph Apel <r.apel at r-apel.de> - 0:5.8.2.1-1jpp
- First JPackage release

* Tue May 03 2005 Ralph Apel <r.apel at r-apel.de> - 0:5.4.7-1jpp
- First JPackage release

